@@ -98,9 +98,6 @@ INVALIDPARAMETER_INCORRECTCOMMONCOUNT = 'InvalidParameter.IncorrectCommonCount'
 # Master节点数量无效。
 INVALIDPARAMETER_INCORRECTMASTERCOUNT = 'InvalidParameter.IncorrectMasterCount'
 
-# core节点的数量不能超过20。
-INVALIDPARAMETER_INVAILDCORECOUNT = 'InvalidParameter.InvaildCoreCount'
-
 # 无效参数，AppId。
 INVALIDPARAMETER_INVALIDAPPID = 'InvalidParameter.InvalidAppId'
 
@@ -110,6 +107,9 @@ INVALIDPARAMETER_INVALIDAUTORENEW = 'InvalidParameter.InvalidAutoRenew'
 # 无效的引导脚本。
 INVALIDPARAMETER_INVALIDBOOTSTRAPACTION = 'InvalidParameter.InvalidBootstrapAction'
 
+# 无效的ClickHouse集群。
+INVALIDPARAMETER_INVALIDCLICKHOUSECLUSTER = 'InvalidParameter.InvalidClickHouseCluster'
+
 # 无效的ClientToken。
 INVALIDPARAMETER_INVALIDCLIENTTOKEN = 'InvalidParameter.InvalidClientToken'
 
@@ -125,6 +125,9 @@ INVALIDPARAMETER_INVALIDCOMPONENT = 'InvalidParameter.InvalidComponent'
 # Core节点数量无效。
 INVALIDPARAMETER_INVALIDCORECOUNT = 'InvalidParameter.InvalidCoreCount'
 
+# CosFileUri参数值无效。
+INVALIDPARAMETER_INVALIDCOSFILEURI = 'InvalidParameter.InvalidCosFileURI'
+
 # 扩容数量必须大于0。
 INVALIDPARAMETER_INVALIDCOUNT = 'InvalidParameter.InvalidCount'
 
@@ -233,6 +236,9 @@ INVALIDPARAMETER_INVALIDSUBNETID = 'InvalidParameter.InvalidSubnetId'
 # 无效的高可用参数。
 INVALIDPARAMETER_INVALIDSUPPORTHA = 'InvalidParameter.InvalidSupportHA'
 
+# 参数错误。
+INVALIDPARAMETER_INVALIDTAGSGROUP = 'InvalidParameter.InvalidTagsGroup'
+
 # task的数量不能超过20。
 INVALIDPARAMETER_INVALIDTASKCOUNT = 'InvalidParameter.InvalidTaskCount'
 
@@ -323,9 +329,6 @@ RESOURCENOTFOUND_TAGSNOTFOUND = 'ResourceNotFound.TagsNotFound'
 # 当前资源规格不存在默认规格。
 RESOURCEUNAVAILABLE_RESOURCESPECNOTDEFAULTSPEC = 'ResourceUnavailable.ResourceSpecNotDefaultSpec'
 
-# 当前资源规格不存在默认规格。
-RESOURCEUNAVAILABLE_RESOURCESPEC_NOTDEFAULTSPEC = 'ResourceUnavailable.ResourceSpec_NotDefaultSpec'
-
 # 资源售罄。
 RESOURCESSOLDOUT = 'ResourcesSoldOut'
 
